
import { Link } from 'react-router-dom';
import { ArrowRight } from 'lucide-react';
import { Button } from '@/components/ui/button';
import { useEffect, useState } from 'react';
import { EnergieCheckLogo } from '@/components/EnergieCheckLogo';

export const Hero = () => {
  const heroImagePath = "/lovable-uploads/eb2a7ee9-48af-4ba3-845a-1e47bd2fcd14.png";
  const [imageLoaded, setImageLoaded] = useState(false);

  useEffect(() => {
    // Preload the hero image
    const preloadImage = new Image();
    preloadImage.src = heroImagePath;
    preloadImage.onload = () => setImageLoaded(true);
  }, []);

  return (
    <section className="relative w-full min-h-screen" aria-labelledby="main-heading">
      <div className="absolute inset-0 z-0">
        <img 
          src={heroImagePath} 
          alt="Energieeffizientes Haus mit Solarpanels und moderner Wärmedämmung" 
          className={`w-full h-full object-cover transition-opacity duration-300 ${imageLoaded ? 'opacity-100' : 'opacity-0'}`}
          loading="eager"
          fetchPriority="high"
          decoding="async"
          sizes="100vw"
          width="1920"
          height="1080"
          onError={e => {
            const target = e.target as HTMLImageElement;
            console.log("Hero image failed to load:", target.src);
            target.style.display = "none";
            target.parentElement!.style.backgroundColor = "#1a2e35";
          }} 
        />
        <div className="absolute inset-0 bg-gradient-to-r from-black/70 via-black/50 to-transparent"></div>
      </div>
      
      <div className="container mx-auto relative z-10 min-h-screen flex flex-col">
        <header className="flex justify-between items-center pt-6 sm:pt-8 px-4">
          <EnergieCheckLogo />
          <nav className="hidden md:flex items-center space-x-8" aria-label="Hauptnavigation">
            <Link to="/" className="text-white/90 hover:text-white text-sm font-medium">
              Home
            </Link>
            <Link to="/blog" className="text-white/90 hover:text-white text-sm font-medium">
              Blog
            </Link>
            <Link to="/quick-check" aria-label="Energie-Check starten">
              <Button variant="moss" size="default">
                Energie-Check starten
              </Button>
            </Link>
          </nav>
        </header>

        <div className="flex-1 flex items-center py-8 sm:py-16 md:py-20 px-4">
          <div className="max-w-3xl text-left space-y-4 sm:space-y-6">
            <h1 id="main-heading" className="text-3xl sm:text-4xl md:text-5xl lg:text-6xl font-bold tracking-tight leading-tight text-white">
              Spare Energie.<br />
              Nutze Förderungen.<br className="sm:hidden" />
              <span className="sm:block">Modernisiere richtig.</span>
            </h1>
            
            <p className="text-base sm:text-lg md:text-xl text-white/90 leading-relaxed">
              Unser Tool analysiert dein Gebäudeprofil in unter 2 Minuten – und zeigt dir, wie du dir staatliche Förderungen von bis zu 24.000 € sichern kannst. Kostenlos, datengestützt und sofort als PDF.
            </p>

            <div className="flex flex-wrap gap-2 sm:gap-3">
              {[{
                icon: <ArrowRight className="h-3 w-3 sm:h-4 sm:w-4 text-moss-dark" aria-hidden="true" />,
                text: "Individuelle Einschätzung"
              }, {
                icon: <ArrowRight className="h-3 w-3 sm:h-4 sm:w-4 text-moss-dark" aria-hidden="true" />,
                text: "Fördercheck"
              }, {
                icon: <ArrowRight className="h-3 w-3 sm:h-4 sm:w-4 text-moss-dark" aria-hidden="true" />,
                text: "Sofortiges Ergebnis"
              }].map((benefit, i) => (
                <div key={i} className="flex items-center gap-1 sm:gap-1.5 text-xs sm:text-sm bg-white/50 backdrop-blur-sm px-2 sm:px-3 py-1 rounded-full">
                  {benefit.icon}
                  <span className="text-foreground/90 font-medium">{benefit.text}</span>
                </div>
              ))}
            </div>
            
            <div className="flex flex-col sm:flex-row gap-3 sm:gap-4 pt-2 sm:pt-4">
              <Link to="/quick-check" aria-label="Energie-Check starten und Förderungen entdecken" className="w-full sm:w-auto">
                <Button size="lg" className="w-full sm:w-auto bg-moss hover:bg-moss-dark text-white gap-2 px-6 sm:px-8 py-4 sm:py-6 text-sm sm:text-base rounded-xl shadow-sm font-semibold">
                  Energie-Check starten
                  <ArrowRight className="h-4 w-4" aria-hidden="true" />
                </Button>
              </Link>
            </div>
            
            <div className="flex items-center gap-2 text-white/80 pt-2">
              <span className="text-xs sm:text-sm">1000+ Nutzer:innen haben bereits den EnergieCheck genutzt</span>
            </div>
          </div>
        </div>
      </div>
    </section>
  );
};
